import { z } from "zod";
declare const TodoItemId: z.ZodObject<{
    id: z.ZodString;
}, "strip", z.ZodTypeAny, {
    id: string;
}, {
    id: string;
}>;
export declare type TodoItemId = z.infer<typeof TodoItemId>;
declare enum TodoStateEnum {
    Todo = "todo",
    InProgress = "in progress",
    Done = "done"
}
declare const TodoItem: z.ZodObject<z.extendShape<{
    id: z.ZodString;
}, {
    label: z.ZodString;
    dueDateMs: z.ZodOptional<z.ZodNumber>;
    state: z.ZodNativeEnum<typeof TodoStateEnum>;
}>, "strip", z.ZodTypeAny, {
    dueDateMs?: number | undefined;
    id: string;
    state: TodoStateEnum;
    label: string;
}, {
    dueDateMs?: number | undefined;
    id: string;
    state: TodoStateEnum;
    label: string;
}>;
export declare type TodoItem = z.infer<typeof TodoItem>;
declare const TodoItems: z.ZodObject<{
    todoItems: z.ZodArray<z.ZodObject<z.extendShape<{
        id: z.ZodString;
    }, {
        label: z.ZodString;
        dueDateMs: z.ZodOptional<z.ZodNumber>;
        state: z.ZodNativeEnum<typeof TodoStateEnum>;
    }>, "strip", z.ZodTypeAny, {
        dueDateMs?: number | undefined;
        id: string;
        state: TodoStateEnum;
        label: string;
    }, {
        dueDateMs?: number | undefined;
        id: string;
        state: TodoStateEnum;
        label: string;
    }>, "many">;
}, "strip", z.ZodTypeAny, {
    todoItems: {
        dueDateMs?: number | undefined;
        id: string;
        state: TodoStateEnum;
        label: string;
    }[];
}, {
    todoItems: {
        dueDateMs?: number | undefined;
        id: string;
        state: TodoStateEnum;
        label: string;
    }[];
}>;
export declare type TodoItems = z.infer<typeof TodoItems>;
declare const TodoItemsGroupedByStatus: z.ZodObject<{
    todo: z.ZodArray<z.ZodObject<z.extendShape<{
        id: z.ZodString;
    }, {
        label: z.ZodString;
        dueDateMs: z.ZodOptional<z.ZodNumber>;
        state: z.ZodNativeEnum<typeof TodoStateEnum>;
    }>, "strip", z.ZodTypeAny, {
        dueDateMs?: number | undefined;
        id: string;
        state: TodoStateEnum;
        label: string;
    }, {
        dueDateMs?: number | undefined;
        id: string;
        state: TodoStateEnum;
        label: string;
    }>, "many">;
    inProgress: z.ZodArray<z.ZodObject<z.extendShape<{
        id: z.ZodString;
    }, {
        label: z.ZodString;
        dueDateMs: z.ZodOptional<z.ZodNumber>;
        state: z.ZodNativeEnum<typeof TodoStateEnum>;
    }>, "strip", z.ZodTypeAny, {
        dueDateMs?: number | undefined;
        id: string;
        state: TodoStateEnum;
        label: string;
    }, {
        dueDateMs?: number | undefined;
        id: string;
        state: TodoStateEnum;
        label: string;
    }>, "many">;
    done: z.ZodArray<z.ZodObject<z.extendShape<{
        id: z.ZodString;
    }, {
        label: z.ZodString;
        dueDateMs: z.ZodOptional<z.ZodNumber>;
        state: z.ZodNativeEnum<typeof TodoStateEnum>;
    }>, "strip", z.ZodTypeAny, {
        dueDateMs?: number | undefined;
        id: string;
        state: TodoStateEnum;
        label: string;
    }, {
        dueDateMs?: number | undefined;
        id: string;
        state: TodoStateEnum;
        label: string;
    }>, "many">;
}, "strip", z.ZodTypeAny, {
    done: {
        dueDateMs?: number | undefined;
        id: string;
        state: TodoStateEnum;
        label: string;
    }[];
    todo: {
        dueDateMs?: number | undefined;
        id: string;
        state: TodoStateEnum;
        label: string;
    }[];
    inProgress: {
        dueDateMs?: number | undefined;
        id: string;
        state: TodoStateEnum;
        label: string;
    }[];
}, {
    done: {
        dueDateMs?: number | undefined;
        id: string;
        state: TodoStateEnum;
        label: string;
    }[];
    todo: {
        dueDateMs?: number | undefined;
        id: string;
        state: TodoStateEnum;
        label: string;
    }[];
    inProgress: {
        dueDateMs?: number | undefined;
        id: string;
        state: TodoStateEnum;
        label: string;
    }[];
}>;
export declare type TodoItemsGroupedByStatus = z.infer<typeof TodoItemsGroupedByStatus>;
declare const FortyTwo: z.ZodLiteral<42>;
export declare type FortyTwo = z.infer<typeof FortyTwo>;
export declare const models: {
    TodoState: z.ZodNativeEnum<typeof TodoStateEnum>;
    TodoItemId: z.ZodObject<{
        id: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        id: string;
    }, {
        id: string;
    }>;
    TodoItem: z.ZodObject<z.extendShape<{
        id: z.ZodString;
    }, {
        label: z.ZodString;
        dueDateMs: z.ZodOptional<z.ZodNumber>;
        state: z.ZodNativeEnum<typeof TodoStateEnum>;
    }>, "strip", z.ZodTypeAny, {
        dueDateMs?: number | undefined;
        id: string;
        state: TodoStateEnum;
        label: string;
    }, {
        dueDateMs?: number | undefined;
        id: string;
        state: TodoStateEnum;
        label: string;
    }>;
    TodoItems: z.ZodObject<{
        todoItems: z.ZodArray<z.ZodObject<z.extendShape<{
            id: z.ZodString;
        }, {
            label: z.ZodString;
            dueDateMs: z.ZodOptional<z.ZodNumber>;
            state: z.ZodNativeEnum<typeof TodoStateEnum>;
        }>, "strip", z.ZodTypeAny, {
            dueDateMs?: number | undefined;
            id: string;
            state: TodoStateEnum;
            label: string;
        }, {
            dueDateMs?: number | undefined;
            id: string;
            state: TodoStateEnum;
            label: string;
        }>, "many">;
    }, "strip", z.ZodTypeAny, {
        todoItems: {
            dueDateMs?: number | undefined;
            id: string;
            state: TodoStateEnum;
            label: string;
        }[];
    }, {
        todoItems: {
            dueDateMs?: number | undefined;
            id: string;
            state: TodoStateEnum;
            label: string;
        }[];
    }>;
    TodoItemsGroupedByStatus: z.ZodObject<{
        todo: z.ZodArray<z.ZodObject<z.extendShape<{
            id: z.ZodString;
        }, {
            label: z.ZodString;
            dueDateMs: z.ZodOptional<z.ZodNumber>;
            state: z.ZodNativeEnum<typeof TodoStateEnum>;
        }>, "strip", z.ZodTypeAny, {
            dueDateMs?: number | undefined;
            id: string;
            state: TodoStateEnum;
            label: string;
        }, {
            dueDateMs?: number | undefined;
            id: string;
            state: TodoStateEnum;
            label: string;
        }>, "many">;
        inProgress: z.ZodArray<z.ZodObject<z.extendShape<{
            id: z.ZodString;
        }, {
            label: z.ZodString;
            dueDateMs: z.ZodOptional<z.ZodNumber>;
            state: z.ZodNativeEnum<typeof TodoStateEnum>;
        }>, "strip", z.ZodTypeAny, {
            dueDateMs?: number | undefined;
            id: string;
            state: TodoStateEnum;
            label: string;
        }, {
            dueDateMs?: number | undefined;
            id: string;
            state: TodoStateEnum;
            label: string;
        }>, "many">;
        done: z.ZodArray<z.ZodObject<z.extendShape<{
            id: z.ZodString;
        }, {
            label: z.ZodString;
            dueDateMs: z.ZodOptional<z.ZodNumber>;
            state: z.ZodNativeEnum<typeof TodoStateEnum>;
        }>, "strip", z.ZodTypeAny, {
            dueDateMs?: number | undefined;
            id: string;
            state: TodoStateEnum;
            label: string;
        }, {
            dueDateMs?: number | undefined;
            id: string;
            state: TodoStateEnum;
            label: string;
        }>, "many">;
    }, "strip", z.ZodTypeAny, {
        done: {
            dueDateMs?: number | undefined;
            id: string;
            state: TodoStateEnum;
            label: string;
        }[];
        todo: {
            dueDateMs?: number | undefined;
            id: string;
            state: TodoStateEnum;
            label: string;
        }[];
        inProgress: {
            dueDateMs?: number | undefined;
            id: string;
            state: TodoStateEnum;
            label: string;
        }[];
    }, {
        done: {
            dueDateMs?: number | undefined;
            id: string;
            state: TodoStateEnum;
            label: string;
        }[];
        todo: {
            dueDateMs?: number | undefined;
            id: string;
            state: TodoStateEnum;
            label: string;
        }[];
        inProgress: {
            dueDateMs?: number | undefined;
            id: string;
            state: TodoStateEnum;
            label: string;
        }[];
    }>;
    FortyTwo: z.ZodLiteral<42>;
};
export {};
